import {FC, useEffect, useState} from "react";
import {Image, View} from "@tarojs/components";
import {HomeApi} from "@/api";
import Taro, {useReachBottom} from "@tarojs/taro";
import styles from "../home.module.scss";
import VideoCover from "@/components/videoCover/videoCover";
import courseTag from '@/static/img/courseTag.png'

const CurRecommended: FC = () => {
  const [page, setPage] = useState(1)
  const [data, setData] = useState<Curriculum[]>([])
  const [total, setTotal] = useState(0)
  const [examine, setExamine] = useState(false)
  const [articles, setArticles] = useState<any[]>([])

  async function getData() {
    const res = await HomeApi.course(page, 4)
    if (res.audit_mode) {
      Taro.setTabBarItem({index: 1, text: '文章'})
      setArticles(res.articles)
      setExamine(res.audit_mode)
      return
    }
    setTotal(res.course.total)
    const newData = res.course.data.reduce((pre, cut) => {
      const index = pre.findIndex(d => d.id === cut.id)
      if (index === -1) {
        pre.push(cut)
      } else {
        pre.splice(index, 1, cut)
      }
      return pre
    }, JSON.parse(JSON.stringify(data)) as Curriculum[])
    setData(newData)
  }

  useEffect(() => {
    getData()
  }, [page])

  useReachBottom(() => {
    data.length < total && setPage(page + 1)
  })

  return (
    <>
      {
        examine ?
          <>
            <View className='text-center my-2'>推荐文章</View>
            {
              articles.map(d => <View className='bg-white p-2 mb-2'>{d.title}</View>)
            }
          </>
          : data.length > 0 && <View>
          <Image src={courseTag} mode='widthFix' className={styles.courseTag}/>
          <View className={'pb-2 flex justify-between flex-wrap ' + styles.videoListBox}>
            {
              data.map(c => <VideoCover
                thumb={c.thumb}
                title={c.title}
                id={c.id}
                depId={c.id}
                key={c.id}
                marker={`共${c.class_hour}节`}
              />)
            }
          </View>
        </View>
      }
      <View className='text-center text-muted font-28'>- 暂无更多 -</View>
    </>
  )
}

export default CurRecommended
